<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">

<!--
SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.

SPDX-License-Identifier: LGPL-3.0-or-later
-->

<context>
    <name>DAboutDialog</name>
    <message>
        <location filename="../widgets/daboutdialog.cpp" line="190"/>
        <source>Acknowledgements</source>
        <translation>Заслуге</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1528"/>
        <source>Version: %1</source>
        <translation>Верзија: %1</translation>
    </message>
    <message>
        <location filename="../widgets/dapplication.cpp" line="1532"/>
        <source>%1 is released under %2</source>
        <translation>%1 је објављен под %2</translation>
    </message>
</context>
<context>
    <name>DCrumbEdit</name>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="840"/>
        <source>Black</source>
        <translation>Црна</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="843"/>
        <source>White</source>
        <translation>Бела</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="846"/>
        <source>Dark Gray</source>
        <translation>Тамно сива</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="849"/>
        <source>Gray</source>
        <translation>Сива</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="852"/>
        <source>Light Gray</source>
        <translation>Светло сива</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="855"/>
        <source>Red</source>
        <translation>Црвена</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="858"/>
        <source>Green</source>
        <translation>Зелена</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="861"/>
        <source>Blue</source>
        <translation>Плава</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="864"/>
        <source>Cyan</source>
        <translation>Цијан</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="867"/>
        <source>Magenta</source>
        <translation>Магента</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="870"/>
        <source>Yellow</source>
        <translation>Жута</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="873"/>
        <source>Dark Red</source>
        <translation>Тамно црвена</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="876"/>
        <source>Dark Green</source>
        <translation>Тамно зелена</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="879"/>
        <source>Dark Blue</source>
        <translation>Тамно плава</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="882"/>
        <source>Dark Cyan</source>
        <translation>Тамно цијан</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="885"/>
        <source>Dark Magenta</source>
        <translation>Тамно магента</translation>
    </message>
    <message>
        <location filename="../widgets/dcrumbedit.cpp" line="888"/>
        <source>Dark Yellow</source>
        <translation>Тамно жута</translation>
    </message>
</context>
<context>
    <name>DInputDialog</name>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../widgets/dinputdialog.cpp" line="43"/>
        <source>Confirm</source>
        <translation>Потврди</translation>
    </message>
</context>
<context>
    <name>DKeySequenceEdit</name>
    <message>
        <location filename="../widgets/dkeysequenceedit.cpp" line="86"/>
        <source>Enter a new shortcut</source>
        <translation>Унесите нову пречицу</translation>
    </message>
</context>
<context>
    <name>DLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="562"/>
        <source>Stop reading</source>
        <translation>Заустави читање</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="564"/>
        <source>Text to Speech</source>
        <translation>Текст у говор</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="587"/>
        <source>Translate</source>
        <translation>Преведи</translation>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="609"/>
        <source>Speech To Text</source>
        <translation>Говор у текст</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewDialogPrivate</name>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="235"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1181"/>
        <source>Advanced</source>
        <translation>Напредно</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="258"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="259"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1597"/>
        <source>Print</source>
        <comment>button</comment>
        <translation>Штампај</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="275"/>
        <source>Basic</source>
        <translation>Основно</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="290"/>
        <source>Printer</source>
        <translation>Штампач</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="304"/>
        <source>Copies</source>
        <translation>Копије</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="324"/>
        <source>Page range</source>
        <translation>Опсег странице</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="326"/>
        <source>All</source>
        <translation>Све</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="327"/>
        <source>Current page</source>
        <translation>Тренутна страница</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="328"/>
        <source>Select pages</source>
        <translation>Изабери странице</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="343"/>
        <source>Orientation</source>
        <translation>Усмерење</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="367"/>
        <source>Portrait</source>
        <translation>Усправно</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="377"/>
        <source>Landscape</source>
        <translation>Положено</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="405"/>
        <source>Pages</source>
        <translation>Странице</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="415"/>
        <source>Color mode</source>
        <translation>Режим боја</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1554"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
        <source>Color</source>
        <translation>Боја</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="417"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1606"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1621"/>
        <source>Grayscale</source>
        <translation>Сиве нијансе</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="428"/>
        <source>Margins</source>
        <translation>Маргине</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Narrow (mm)</source>
        <translation>Уско (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Normal (mm)</source>
        <translation>Нормално (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Moderate (mm)</source>
        <translation>Умерено (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="430"/>
        <source>Customize (mm)</source>
        <translation>Прилагоди (mm)</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="436"/>
        <source>Top</source>
        <translation>Врх</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="439"/>
        <source>Left</source>
        <translation>Лево</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="442"/>
        <source>Bottom</source>
        <translation>Дно</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="445"/>
        <source>Right</source>
        <translation>Десно</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="490"/>
        <source>Scaling</source>
        <translation>Скалирање</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="504"/>
        <source>Actual size</source>
        <translation>Стварна величина</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="513"/>
        <source>Scale</source>
        <translation>Скалирај</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="544"/>
        <source>Paper</source>
        <translation>Папир</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="554"/>
        <source>Paper size</source>
        <translation>Величина папира</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="567"/>
        <source>Print Layout</source>
        <translation>Приказ пре штампања</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="578"/>
        <source>Duplex</source>
        <translation>Двострано</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="591"/>
        <source>N-up printing</source>
        <translation>Страница по листу</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>2 pages/sheet, 1×2</source>
        <translation>2 странице/лист, 1×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>4 pages/sheet, 2×2</source>
        <translation>4 странице/лист, 2×2</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>6 pages/sheet, 2×3</source>
        <translation>6 страница/лист, 2×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>9 pages/sheet, 3×3</source>
        <translation>9 страница/лист, 3×3</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="593"/>
        <source>16 pages/sheet, 4×4</source>
        <translation>16 страница/лист, 4×4</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="602"/>
        <source>Layout direction</source>
        <translation>Усмерење распореда</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="647"/>
        <source>Page Order</source>
        <translation>Редослед страница</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="658"/>
        <source>Collate pages</source>
        <translation>Поређај странице</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="664"/>
        <source>Print pages in order</source>
        <translation>Штампај странице по реду</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
        <source>Front to back</source>
        <translation>Напред ка назад</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="666"/>
        <source>Back to front</source>
        <translation>Назад ка напред</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="690"/>
        <source>Watermark</source>
        <translation>Водени жиг</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="701"/>
        <source>Add watermark</source>
        <translation>Додај водени жиг</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="743"/>
        <source>Text watermark</source>
        <translation>Текстуални водени жиг</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Confidential</source>
        <translation>Поверљиво</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Draft</source>
        <translation>Нацрт</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Sample</source>
        <translation>Узорак</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="745"/>
        <source>Custom</source>
        <translation>Прилагођено</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="753"/>
        <source>Input your text</source>
        <translation>Унесите текст</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="776"/>
        <source>Picture watermark</source>
        <translation>Сликовни водени жиг</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="797"/>
        <source>Layout</source>
        <translation>Распоред</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
        <source>Tile</source>
        <translation>Поплочано</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="799"/>
        <source>Center</source>
        <translation>Центрирано</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="810"/>
        <source>Angle</source>
        <translation>Угао</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="826"/>
        <source>Size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="847"/>
        <source>Transparency</source>
        <translation>Провидност</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="904"/>
        <source>Print to PDF</source>
        <translation>Испис у ПДФ</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="905"/>
        <source>Save as Image</source>
        <translation>Сачувај као слику</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1177"/>
        <source>Collapse</source>
        <translation>Скупи</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1300"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1307"/>
        <source>Flip on short edge</source>
        <translation>Oкрећи по краћој ивици</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1303"/>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1306"/>
        <source>Flip on long edge</source>
        <translation>Окрећи по дужој ивици</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1397"/>
        <source>Input page numbers please</source>
        <translation>Унесите бројеве страница</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1400"/>
        <source>Maximum page number reached</source>
        <translation>Достигнут је максималан број страница</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1403"/>
        <source>Input English comma please</source>
        <translation>Молимо унесите енглеску запету</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1406"/>
        <source>Input page numbers like this: 1,3,5-7,11-15,18,21</source>
        <translation>Унеси бројеве страница овако: 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1559"/>
        <source>Save</source>
        <comment>button</comment>
        <translation>Сачувај</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
        <source>*.pdf</source>
        <translation>*.pdf</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="1673"/>
        <source>For example, 1,3,5-7,11-15,18,21</source>
        <translation>На пример, 1,3,5-7,11-15,18,21</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2174"/>
        <source>Save as PDF</source>
        <translation>Сачувај као ПДФ</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2213"/>
        <source>Save as image</source>
        <translation>Сачувај као слику</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewdialog.cpp" line="2215"/>
        <source>Images</source>
        <translation>Слике</translation>
    </message>
</context>
<context>
    <name>DPrintPreviewWidget</name>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1619"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1622"/>
        <source>Confidential</source>
        <translation>Поверљиво</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1637"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1640"/>
        <source>Draft</source>
        <translation>Нацрт</translation>
    </message>
    <message>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1655"/>
        <location filename="../widgets/dprintpreviewwidget.cpp" line="1658"/>
        <source>Sample</source>
        <translation>Узорак</translation>
    </message>
</context>
<context>
    <name>DSearchEdit</name>
    <message>
        <location filename="../widgets/dsearchedit.cpp" line="297"/>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
</context>
<context>
    <name>DSettingsDialog</name>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="78"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="79"/>
        <source>Replace</source>
        <translation>Замени</translation>
    </message>
    <message>
        <location filename="../widgets/dsettingswidgetfactory.cpp" line="81"/>
        <source>This shortcut conflicts with %1, click on Add to make this shortcut effective immediately</source>
        <translation>Ова пречица је у сукобу са %1, кликните на Додај да пречица ступи на снагу</translation>
    </message>
</context>
<context>
    <name>DShortcutEdit</name>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="31"/>
        <source>Please input a new shortcut</source>
        <translation>Унесите нову пречицу</translation>
    </message>
    <message>
        <location filename="../widgets/dshortcutedit.cpp" line="102"/>
        <source>None</source>
        <translation>Ништа</translation>
    </message>
</context>
<context>
    <name>DSplitScreenWidget</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="215"/>
        <source>Unmaximize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="218"/>
        <source>Maximize</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="258"/>
        <source>Tile window to left of screen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="259"/>
        <source>Tile window to right of screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DTextEdit</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="185"/>
        <source>Stop reading</source>
        <translation>Заустави читање</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="187"/>
        <source>Text to Speech</source>
        <translation>Текст у говор</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="210"/>
        <source>Translate</source>
        <translation>Преведи</translation>
    </message>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="232"/>
        <source>Speech To Text</source>
        <translation>Говор у текст</translation>
    </message>
</context>
<context>
    <name>PickColorWidget</name>
    <message>
        <location filename="../widgets/dprintpickcolorwidget.cpp" line="110"/>
        <source>Color</source>
        <translation>Боја</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="536"/>
        <source>&amp;Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="539"/>
        <source>Cu&amp;t</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dlineedit.cpp" line="545"/>
        <source>Select All</source>
        <translation>Изабери све</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../widgets/dsimplelistview.cpp" line="1366"/>
        <source>No search result</source>
        <translation>Нема резултата претраге</translation>
    </message>
    <message>
        <location filename="../widgets/private/settings/content.cpp" line="340"/>
        <source>Restore Defaults</source>
        <translation>Врати Подразумевано</translation>
    </message>
</context>
<context>
    <name>QWidgetTextControl</name>
    <message>
        <location filename="../widgets/dtextedit.cpp" line="177"/>
        <source>Select All</source>
        <translation>Изабери све</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../widgets/private/settings/shortcutedit.cpp" line="117"/>
        <source>Please enter a new shortcut</source>
        <translation>Унесите нову пречицу</translation>
    </message>
</context>
<context>
    <name>TitleBarMenu</name>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="770"/>
        <source>Theme</source>
        <translation>Тема</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="772"/>
        <source>Light Theme</source>
        <translation>Светла тема</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="773"/>
        <source>Dark Theme</source>
        <translation>Тамна тема</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="774"/>
        <source>System Theme</source>
        <translation>Системска тема</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="799"/>
        <source>Help</source>
        <translation>Помоћ</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="807"/>
        <source>Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="814"/>
        <source>About</source>
        <translation>О програму</translation>
    </message>
    <message>
        <location filename="../widgets/dtitlebar.cpp" line="821"/>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
</context>
</TS>